@@ -10,14 +10,15 @@
 #include <QObject>
 #include <QPointer>
 #include <faces/SensorFaceController.h>
+#include <qqmlregistration.h>
 class QQuickItem;
 
-
 class FaceLoader : public QObject
 {
     Q_OBJECT
     Q_PROPERTY(PageDataObject *dataObject READ dataObject WRITE setDataObject NOTIFY dataObjectChanged)
     Q_PROPERTY(KSysGuard::SensorFaceController *controller READ controller NOTIFY controllerChanged)
+    QML_ELEMENT
 
 public:
     explicit FaceLoader(QObject *parent = nullptr);
